numpy.dtype
===========

.. currentmodule:: numpy

.. autoclass:: dtype

   

   .. HACK
      .. autosummary::
         :toctree:
      
         dtype.__init__
         dtype.newbyteorder



   

   .. HACK
      .. autosummary::
         :toctree:
      
         dtype.alignment
         dtype.base
         dtype.byteorder
         dtype.char
         dtype.descr
         dtype.fields
         dtype.flags
         dtype.hasobject
         dtype.isbuiltin
         dtype.isnative
         dtype.itemsize
         dtype.kind
         dtype.metadata
         dtype.name
         dtype.names
         dtype.num
         dtype.shape
         dtype.str
         dtype.subdtype
         dtype.type

